/*
 * blink.cpp
 * ATmega8 mit 1 MHz
 * PORTB wird ueber ein Timer alle 0.263s ein- und ausgeschaltet. Das entspricht 3.81Hz
 *
 * Der Takt beträgt 1Mhz. Der Timer Prescaler ist auf 1024 eingestellt und ein 8 Bit Timer
 * läuft nach 256 Increments über. Also
 * 1000000Hz / 1024 / 256 = 3.81Hz
 */

#include <avr/io.h>
#include <avr/interrupt.h>

// Overflow Interrupt Routine von Timer 0
ISR(TIMER0_OVF_vect) {
  // PORTB inventieren
  PORTB =~ PORTB;
}

int main() {
  // PORTB als Ausgang schalten
  DDRB  = 0xFF;
  // Alle Ausgaenge auf 0 schalten
  PORTB = 0x00;

  // Prescaler von Timer0 auf 1024 stellen
  TCCR0 |= (1 << CS02) | (1 << CS00);
  // Timer 0 Overflow Interrupt aktivieren
  TIMSK  |= (1 << TOIE0);

  // Interrupts einschalten
  sei();

  // Endlosschleife. Hier ist kein weiterer Code nötig.
  // Das Ein und Ausschalten der LED geschiet in der Overflow Interrupt Routine
  for(;;);
}
